#include <Adafruit_SSD1306.h>
#include <Fonts/FreeMono18pt7b.h>
#include <Fonts/FreeSansBold9pt7b.h>
#include <Fonts/FreeSerifItalic12pt7b.h>

#define OLED_I2C_ADDRESS 0x3C
#define OLED_WIDTH 128
#define OLED_HEIGHT 64

Adafruit_SSD1306 oled(OLED_WIDTH, OLED_HEIGHT);

void setup() {
  if (!oled.begin(SSD1306_SWITCHCAPVCC, OLED_I2C_ADDRESS)) {
    while (true);
  }
  oled.clearDisplay();
  showHeader();
  oled.display();
}

void loop() {
  showFontMono();
  oled.display();
  delay(1000);
  
  showFontSans();
  oled.display();
  delay(1000);
  
  showFontSerif();
  oled.display();
  delay(1000);
}

void showFontMono() {
  oled.fillRect(0, 16, 128, 48, BLACK);
  oled.setFont(&FreeMono18pt7b);
  oled.setCursor(OLED_WIDTH / 2, OLED_HEIGHT / 2 + 8);
  printCenteredText("Mono");
}

void showFontSans() {
  oled.fillRect(0, 16, 128, 48, BLACK);
  oled.setFont(&FreeSansBold9pt7b);
  oled.setCursor(OLED_WIDTH / 2, OLED_HEIGHT / 2 + 8);
  printCenteredText("Sans bold");
}

void showFontSerif() {
  oled.fillRect(0, 16, 128, 48, BLACK);
  oled.setFont(&FreeSerifItalic12pt7b);
  oled.setCursor(OLED_WIDTH / 2, OLED_HEIGHT / 2 + 8);
  printCenteredText("Serif italic");
}

void showHeader() {
  oled.setFont();
  oled.setTextSize(1);
  oled.setTextColor(WHITE);
  oled.setCursor(OLED_WIDTH / 2, 8);
  printCenteredText("Font");
}

void printCenteredText(String text) {
  int16_t x = 0, y = 0;
  uint16_t w = 0, h = 0;
  int16_t cursorX = oled.getCursorX();
  int16_t cursorY = oled.getCursorY();
  oled.getTextBounds(text, 0, 0, &x, &y, &w, &h);
  oled.setCursor(cursorX - x - w / 2, cursorY - y - h / 2);
  oled.print(text);
}